@@ -25,12 +25,12 @@ module Sass
           denominator_units = []
         when ::Hash
           numerator_units = unit.fetch(:numerator_units, [])
-          unless numerator_units.is_a?(Array)
+          unless numerator_units.is_a?(::Array)
             raise Sass::ScriptError, "invalid numerator_units #{numerator_units.inspect}"
           end
 
           denominator_units = unit.fetch(:denominator_units, [])
-          unless denominator_units.is_a?(Array)
+          unless denominator_units.is_a?(::Array)
             raise Sass::ScriptError, "invalid denominator_units #{denominator_units.inspect}"
           end
         else
@@ -99,7 +99,7 @@ module Sass
 
       # @return [Integer]
       def hash
-        @hash ||= FuzzyMath.hash(canonical_units_value)
+        @hash ||= FuzzyMath._hash(canonical_units_value).hash
       end
 
       # @return [::Boolean]
@@ -275,17 +275,15 @@ module Sass
                                   name: nil,
                                   other: nil,
                                   other_name: nil)
-        if other && (other.numerator_units != new_denominator_units && other.denominator_units != new_denominator_units)
-          raise Sass::ScriptError, "Expect #{other} to have units #{unit_string(new_numerator_units,
-                                                                                new_denominator_units).inspect}"
+        unless other.nil? ||
+               (other.numerator_units == new_numerator_units && other.denominator_units == new_denominator_units)
+          raise Sass::ScriptError,
+                "Expected #{other} to have units #{unit_string(new_numerator_units, new_denominator_units).inspect}"
         end
 
         return value if numerator_units == new_numerator_units && denominator_units == new_denominator_units
 
-        return value if numerator_units == new_numerator_units && denominator_units == new_denominator_units
-
         other_unitless = new_numerator_units.empty? && new_denominator_units.empty?
-
         return value if coerce_unitless && (unitless? || other_unitless)
 
         compatibility_error = lambda {
